@@ -1,13 +1,21 @@
 use wasmy_abi::*;
 
 use crate::{instance, WasmUri};
+use crate::modules::{FnBuildImportObject, FnCheckModule};
 use crate::wasm_file::WasmFile;
 
 pub fn load_wasm<B, W>(wasm_file: W) -> Result<WasmCaller>
     where B: AsRef<[u8]>,
           W: WasmFile<B>,
 {
-    Ok(WasmCaller(instance::load(wasm_file)?))
+    Ok(WasmCaller(instance::load(wasm_file, None, None)?))
+}
+
+pub fn custom_load_wasm<B, W>(wasm_file: W, check_module: Option<FnCheckModule>, build_import_object: Option<FnBuildImportObject>) -> Result<WasmCaller>
+    where B: AsRef<[u8]>,
+          W: WasmFile<B>,
+{
+    Ok(WasmCaller(instance::load(wasm_file, check_module, build_import_object)?))
 }
 
 #[derive(Clone, Hash, Eq, PartialEq, Debug)]
@@ -32,13 +40,13 @@ impl WasmCaller {
     pub fn call<A: Message, R: Message>(&self, method: Method, data: A) -> Result<R> {
         let in_args = InArgs::try_new(method, data)?;
         instance::with(self.0.clone(), |ins| -> Result<R>{
-            ins.call_wasm_handler(None::<Empty>, method, in_args)?.into()
+            ins.call_wasmy_wasm_handler(None::<Empty>, method, in_args)?.into()
         })
     }
     pub fn ctx_call<C: Message, A: Message, R: Message>(&self, ctx: C, method: Method, data: A) -> Result<R> {
         let in_args = InArgs::try_new(method, data)?;
         instance::with(self.0.clone(), |ins| -> Result<R>{
-            ins.call_wasm_handler(Some(ctx), method, in_args)?.into()
+            ins.call_wasmy_wasm_handler(Some(ctx), method, in_args)?.into()
         })
     }
 }
